@@ -37,6 +37,11 @@ class AssignmentTest(unittest.TestCase):
         self.assertEqual(a.x, 42)
         self.assertEqual(a.y, 43)
 
+    def test_custom_salt(self):
+        a = Assignment(self.tester_salt)
+        custom_salt = lambda x,y: '%s-%s' % (x,y)
+        a.foo = UniformChoice(choices=list(range(8)), unit=self.tester_unit)
+        self.assertEqual(a.foo, 7)
 
 if __name__ == '__main__':
     unittest.main()
